==> polyrate9.0.tar.gz: polyrate9.0/src/headr.f <==
C***********************************************************************
C  HEADR
C***********************************************************************
C
      SUBROUTINE headr
C
C     PRINTS OUT PROGRAM HEADER TO UNIT FU6
C
C     CALLED BY:
C                MAIN
C
C
C   INCLUDE FILE ADDED 15/09.01
C   FORMAT STATEMENTS MODIFIED TO MAKE OUTPUT MORE CLEAR 
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      include 'param.inc'                                               1508GL91
C
C
      WRITE (FU6,1000)
      WRITE (FU6,1100)
      WRITE (FU6,1200)
      WRITE (FU6,1300)
      WRITE (FU6,1400)
      WRITE (FU6,1500)
      WRITE (FU6,1600)
      WRITE (FU6,1700)
      WRITE (FU6,1300)
      WRITE (FU6,1800)  
      WRITE (FU6,1900)
      WRITE (FU6,1000)
C
C
      RETURN
C
 1000 FORMAT (/,80(1H*))
 1100 FORMAT (/3X,'POLYRATE version 9.0 (May, 2002)',/)
 1200 FORMAT (3X,'Jose C. Corchado, Yao-Yuan Chuang, Patton L. Fast,',
     *       /3X,'Jordi Villa, Wei-Ping Hu, Yi-Ping Liu,', 
     *       /3X,'Gillian C. Lynch, Kiet A. Nguyen, Charles F. Jackels,',
     *       /3X,'Vasilios S. Melissas, Benjamin J. Lynch, Ivan Rossi,',
     *       /3X,'Elena L. Coitino, Antonio Fernandez Ramos, ',
     *       /3X,'Jingzhi Pu, and Titus V. Albu') 
 1300 FORMAT (3X,'Department of Chemistry and Supercomputer Institute',
     *       /3X,'University of Minnesota, Minneapolis, Minnesota',/)
 1400 FORMAT (3X,'Rozeanne Steckler',
     *     /3X,'San Diego Supercomputer Center, La Jolla, California',/)
 1500 FORMAT (3X,'Bruce C. Garrett',
     *       /3X,'Environmental Molecular Sciences Laboratory',
     *       /3X,'Pacific Northwest Laboratory, Richland, Washington',/)
 1600 FORMAT (3X,'Alan D. Isaacson',
     *       /3X,'Department of Chemistry, Miami University, ',
     *           'Oxford, Ohio',/)
 1700 FORMAT (3X,'and Donald G. Truhlar')    
 1800 FORMAT (3X,'A program for the analysis of reactants,', 
     *           ' products, transition states, and',/3X,
     *           'generalized transition states, and for the',   
     *           ' calculation of variational',/3X, 
     *           'transition state theory rate constants and', 
     *           ' multidimensional semiclassical',/,3X,'tunneling ', 
     *           'probabilities, including direct dynamics.',//) 
 1900 FORMAT (3X,'Copyright 1988-2002',
     *       /3X,'Donald G. Truhlar and ',
     *           'Regents of the University of Minnesota')
C
      END

==> polyrate9.1.tar.gz: polyrate9.1/src/headr.f <==
C***********************************************************************
C  HEADR
C***********************************************************************
C
      SUBROUTINE headr
C
C     PRINTS OUT PROGRAM HEADER TO UNIT FU6
C
C     CALLED BY:
C                MAIN
C
C
C   INCLUDE FILE ADDED 15/09.11
C   FORMAT STATEMENTS MODIFIED TO MAKE OUTPUT MORE CLEAR 
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      include 'param.inc'                                               1508GL91
C
C
      WRITE (FU6,1000)
      WRITE (FU6,1100)
      WRITE (FU6,1200)
      WRITE (FU6,1300)
      WRITE (FU6,1400)
      WRITE (FU6,1500)
      WRITE (FU6,1600)
      WRITE (FU6,1700)
      WRITE (FU6,1300)
      WRITE (FU6,1800)  
      WRITE (FU6,1900)
      WRITE (FU6,1000)
C
C
      RETURN
C
 1000 FORMAT (/,80(1H*))
 1100 FORMAT (/3X,'POLYRATE version 9.1 (July, 2002)',/)
 1200 FORMAT (3X,'Jose C. Corchado, Yao-Yuan Chuang, Patton L. Fast,',
     *       /3X,'Jordi Villa, Wei-Ping Hu, Yi-Ping Liu,', 
     *       /3X,'Gillian C. Lynch, Kiet A. Nguyen, Charles F. Jackels,',
     *       /3X,'Vasilios S. Melissas, Benjamin J. Lynch, Ivan Rossi,',
     *       /3X,'Elena L. Coitino, Antonio Fernandez Ramos, ',
     *       /3X,'Jingzhi Pu, and Titus V. Albu') 
 1300 FORMAT (3X,'Department of Chemistry and Supercomputer Institute',
     *       /3X,'University of Minnesota, Minneapolis, Minnesota',/)
 1400 FORMAT (3X,'Rozeanne Steckler',
     *     /3X,'San Diego Supercomputer Center, La Jolla, California',/)
 1500 FORMAT (3X,'Bruce C. Garrett',
     *       /3X,'Environmental Molecular Sciences Laboratory',
     *       /3X,'Pacific Northwest Laboratory, Richland, Washington',/)
 1600 FORMAT (3X,'Alan D. Isaacson',
     *       /3X,'Department of Chemistry, Miami University, ',
     *           'Oxford, Ohio',/)
 1700 FORMAT (3X,'and Donald G. Truhlar')    
 1800 FORMAT (3X,'A program for the analysis of reactants,', 
     *           ' products, transition states, and',/3X,
     *           'generalized transition states, and for the',   
     *           ' calculation of variational',/3X, 
     *           'transition state theory rate constants and', 
     *           ' multidimensional semiclassical',/,3X,'tunneling ', 
     *           'probabilities, including direct dynamics.',//) 
 1900 FORMAT (3X,'Copyright 1988-2002',
     *       /3X,'Donald G. Truhlar and ',
     *           'Regents of the University of Minnesota')
C
      END
